@@ -1,4 +1,4 @@
-fmri.smooth <- function(spm,hmax=4,adaptive=TRUE,lkern="Triangle",skern="Triangle",na.rm=FALSE) {
+fmri.smooth <- function(spm,hmax=4,adaptive=TRUE,lkern="Gaussian",skern="Plateau",na.rm=FALSE) {
   cat("fmri.smooth: entering function\n")
   
   if (!("fmrispm" %in% class(spm))) {
@@ -271,7 +271,8 @@ plot.fmridata <- function(x, anatomic = NULL , maxpvalue =
     signal[is.na(signal)] <- 0
     signal[is.infinite(signal)] <- 0
 
-    quant <- if (x$smooth) qnorm(1-maxpvalue) else qt(1-maxpvalue,length(hrf))
+    ## check !!!!
+    quant <- if (!is.null(attr(spm, "smooth"))) qnorm(1-maxpvalue) else qt(1-maxpvalue,length(hrf)) 
     
     if (type == "3d") {
       if (spm) {
